powered by
ggplot
Takes a vector of messages and returns a ggplot object with the text in the figure. This can be used in automated figure generation to cascade an error message to the end user.
mk_error_fig(msgs)
ggplot object
Vector of error messages
mk_error_fig("This is an error")
Run the code above in your browser using DataLab